@@ -1,5 +1,5 @@
 package ZMQ::Raw::Socket;
-$ZMQ::Raw::Socket::VERSION = '0.06';
+$ZMQ::Raw::Socket::VERSION = '0.07';
 use strict;
 use warnings;
 use Carp;
@@ -31,12 +31,22 @@ ZMQ::Raw::Socket - ZeroMQ Socket class
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
 A L<ZMQ::Raw::Socket> represents a ZeroMQ socket.
 
+=head1 SYNOPSIS
+
+	use ZMQ::Raw;
+
+	# receive a single message-part
+	my $msg = $socket->recvmsg();
+
+	# receive all message parts
+	my @msgs = $socket->recvmsg();
+
 =head1 METHODS
 
 =head2 new( $context, $type )
@@ -122,9 +132,9 @@ follow.
 
 =back
 
-=head2 sendmsg( $msg, $flags = 0)
+=head2 sendmsg( @msgs, $flags = 0)
 
-Queue C<$msg> to be sent.
+Queue C<@msgs> to be sent.
 
 =head2 recv( $flags = 0)
 
@@ -135,7 +145,8 @@ method will return C<undef> immediately.
 
 =head2 recvmsg( $flags = 0)
 
-Receive a message part. Returns a L<C<ZMQ::Raw::Message>> object.
+Receive a message part or multiple messages parts if called in list context.
+Returns a L<C<ZMQ::Raw::Message>> object or an array of object.
 
 =head2 setsockopt( $option, $value )
 
